==> libmongocrypt_1.2.1.orig.tar.gz: libmongocrypt-1.2.1/bindings/node/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

### [1.2.6](https://github.com/mongodb/libmongocrypt/compare/node-v1.2.5...node-v1.2.6) (2021-07-01)

### [1.2.5](https://github.com/mongodb/libmongocrypt/compare/node-v1.2.4...node-v1.2.5) (2021-06-10)

### [1.2.4](https://github.com/mongodb/libmongocrypt/compare/node-v1.2.3...node-v1.2.4) (2021-06-01)

### [1.2.3](https://github.com/mongodb/libmongocrypt/compare/node-v1.2.2...node-v1.2.3) (2021-04-06)

### [1.2.2](https://github.com/mongodb/libmongocrypt/compare/node-v1.2.1...node-v1.2.2) (2021-03-16)

### [1.2.1](https://github.com/mongodb/libmongocrypt/compare/node-v1.2.0...node-v1.2.1) (2021-02-05)

## [1.2.0](https://github.com/mongodb/libmongocrypt/compare/node-v1.1.0...node-v1.2.0) (2021-02-02)

### [1.1.1-beta.0](https://github.com/mongodb/libmongocrypt/compare/node-v1.1.0...node-v1.1.1-beta.0) (2020-12-04)

# [1.1.0](https://github.com/mongodb/libmongocrypt/compare/node-v1.0.1...node-v1.1.0) (2020-06-23)



## [1.0.1](https://github.com/mongodb/libmongocrypt/compare/node-v1.0.0...1.0.1) (2019-12-31)



# [1.0.0](https://github.com/mongodb/libmongocrypt/compare/node-v1.0.0-rc3.0...1.0.0) (2019-12-10)



# [1.0.0-rc3.0](https://github.com/mongodb/libmongocrypt/compare/node-v1.0.0-rc2.0...1.0.0-rc3.0) (2019-12-04)



# [1.0.0-rc2.0](https://github.com/mongodb/libmongocrypt/compare/node-v1.0.0-rc1.0...1.0.0-rc2.0) (2019-12-04)



# [1.0.0-rc1.0](https://github.com/mongodb/libmongocrypt/compare/node-v1.0.0-rc0...1.0.0-rc1.0) (2019-12-04)

==> libmongocrypt_1.3.0.orig.tar.gz: libmongocrypt-1.3.0/bindings/node/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

## [2.0.0-beta.0](https://github.com/mongodb/libmongocrypt/compare/node-v1.2.7...node-v2.0.0-beta.0) (2021-10-07)

### [1.2.7](https://github.com/mongodb/libmongocrypt/compare/node-v1.2.6...node-v1.2.7) (2021-09-14)

### [1.2.6](https://github.com/mongodb/libmongocrypt/compare/node-v1.2.5...node-v1.2.6) (2021-07-01)

### [1.2.5](https://github.com/mongodb/libmongocrypt/compare/node-v1.2.4...node-v1.2.5) (2021-06-10)

### [1.2.4](https://github.com/mongodb/libmongocrypt/compare/node-v1.2.3...node-v1.2.4) (2021-06-01)

### [1.2.3](https://github.com/mongodb/libmongocrypt/compare/node-v1.2.2...node-v1.2.3) (2021-04-06)

### [1.2.2](https://github.com/mongodb/libmongocrypt/compare/node-v1.2.1...node-v1.2.2) (2021-03-16)

### [1.2.1](https://github.com/mongodb/libmongocrypt/compare/node-v1.2.0...node-v1.2.1) (2021-02-05)

## [1.2.0](https://github.com/mongodb/libmongocrypt/compare/node-v1.1.0...node-v1.2.0) (2021-02-02)

### [1.1.1-beta.0](https://github.com/mongodb/libmongocrypt/compare/node-v1.1.0...node-v1.1.1-beta.0) (2020-12-04)

# [1.1.0](https://github.com/mongodb/libmongocrypt/compare/node-v1.0.1...node-v1.1.0) (2020-06-23)



## [1.0.1](https://github.com/mongodb/libmongocrypt/compare/node-v1.0.0...1.0.1) (2019-12-31)



# [1.0.0](https://github.com/mongodb/libmongocrypt/compare/node-v1.0.0-rc3.0...1.0.0) (2019-12-10)



# [1.0.0-rc3.0](https://github.com/mongodb/libmongocrypt/compare/node-v1.0.0-rc2.0...1.0.0-rc3.0) (2019-12-04)



# [1.0.0-rc2.0](https://github.com/mongodb/libmongocrypt/compare/node-v1.0.0-rc1.0...1.0.0-rc2.0) (2019-12-04)



# [1.0.0-rc1.0](https://github.com/mongodb/libmongocrypt/compare/node-v1.0.0-rc0...1.0.0-rc1.0) (2019-12-04)
